/*******************************************************************************
* File Name: SAIDA.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SAIDA.h"

static SAIDA_BACKUP_STRUCT  SAIDA_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: SAIDA_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function applies only to SIO and USBIO pins.
*  It should not be called for GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet SAIDA_SUT.c usage_SAIDA_Sleep_Wakeup
*******************************************************************************/
void SAIDA_Sleep(void)
{
    #if defined(SAIDA__PC)
        SAIDA_backup.pcState = SAIDA_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            SAIDA_backup.usbState = SAIDA_CR1_REG;
            SAIDA_USB_POWER_REG |= SAIDA_USBIO_ENTER_SLEEP;
            SAIDA_CR1_REG &= SAIDA_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(SAIDA__SIO)
        SAIDA_backup.sioState = SAIDA_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        SAIDA_SIO_REG &= (uint32)(~SAIDA_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: SAIDA_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep(). This 
* function applies only to SIO and USBIO pins. It should not be called for
* GPIO or GPIO_OVT pins.
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to SAIDA_Sleep() for an example usage.
*******************************************************************************/
void SAIDA_Wakeup(void)
{
    #if defined(SAIDA__PC)
        SAIDA_PC = SAIDA_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            SAIDA_USB_POWER_REG &= SAIDA_USBIO_EXIT_SLEEP_PH1;
            SAIDA_CR1_REG = SAIDA_backup.usbState;
            SAIDA_USB_POWER_REG &= SAIDA_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(SAIDA__SIO)
        SAIDA_SIO_REG = SAIDA_backup.sioState;
    #endif
}


/* [] END OF FILE */
